==> highlight-vue-1.1.3.tgz: package/lib/components/Highlight.js <==
/*!
 * highlight-vue v1.1.3
 * (c) 2019-2021 yujinpan
 * Released under the MIT License.
 */

import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import 'core-js/modules/es.string.trim.js';
import highlight from 'highlight.js/lib/core';
import styleInject from 'style-inject/dist/style-inject.es.js';
import __vue_normalize__ from 'vue-runtime-helpers/dist/normalize-component.js';

var script = {
  functional: true,
  props: {
    code: {
      type: String,
      required: true
    },
    lang: {
      type: String,
      default: 'xml'
    },
    pre: {
      type: Boolean,
      default: true
    }
  },
  render: function render(h, _ref) {
    var props = _ref.props,
        data = _ref.data;
    var code = highlight.highlight(props.lang, props.code.trim()).value;
    return props.pre ? h("pre", _mergeJSXProps([{
      "class": "highlight-vue"
    }, data]), [h("code", {
      "domProps": _objectSpread({}, {
        innerHTML: code
      })
    })]) : h("code", _mergeJSXProps([{
      "class": "highlight-vue"
    }, _objectSpread(_objectSpread({}, data), {}, {
      domProps: {
        innerHTML: code
      }
    })]));
  }
};

var css_248z = "code.highlight-vue,pre.highlight-vue{border:1px solid #e5e5e5;border-radius:2px;background-color:#fafafa}code.highlight-vue,pre.highlight-vue code{padding:2px 4px;font-size:86%;font-family:Menlo,DejaVu Sans Mono,Liberation Mono,Consolas,Ubuntu Mono,Courier New,andale mono,lucida console,monospace}pre.highlight-vue{font-size:.9em;overflow:auto;padding:16px 24px;line-height:1.6;word-break:break-all;word-wrap:break-word}pre.highlight-vue code{padding:unset;font-size:inherit;background:unset;border:unset;border-radius:unset}";
styleInject(css_248z);

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/__vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;

==> highlight-vue-1.1.4.tgz: package/lib/components/Highlight.js <==
/*!
 * highlight-vue v1.1.4
 * (c) 2019-2022 yujinpan
 * Released under the MIT License.
 */

import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';
import _objectSpread from '@babel/runtime/helpers/esm/objectSpread2';
import 'core-js/modules/es.string.trim.js';
import prism from 'prismjs';
import 'prismjs/components/prism-markup';
import 'prismjs/components/prism-css';
import 'prismjs/components/prism-sass';
import 'prismjs/components/prism-javascript';
import 'prismjs/components/prism-typescript';
import 'prismjs/components/prism-bash';
import styleInject from 'style-inject/dist/style-inject.es.js';
import __vue_normalize__ from 'vue-runtime-helpers/dist/normalize-component.js';

var script = {
  functional: true,
  props: {
    code: {
      type: String,
      required: true
    },
    lang: {
      type: String,
      default: 'vue'
    },
    pre: {
      type: Boolean,
      default: true
    }
  },
  render: function render(h, _ref) {
    var props = _ref.props,
        data = _ref.data;
    var lang = {
      vue: 'markup',
      html: 'markup',
      md: 'markdown',
      ts: 'typescript',
      sh: 'bash',
      shell: 'bash'
    }[props.lang] || props.lang;
    var code = prism.highlight(props.code.trim(), prism.languages[lang], lang);
    return props.pre ? h("pre", _mergeJSXProps([{
      "class": "highlight-vue language-".concat(lang)
    }, data]), [h("code", {
      "domProps": _objectSpread({}, {
        innerHTML: code
      })
    })]) : h("code", _mergeJSXProps([{
      "class": "highlight-vue language-".concat(lang)
    }, _objectSpread(_objectSpread({}, data), {}, {
      domProps: {
        innerHTML: code
      }
    })]));
  }
};

var css_248z = "pre.highlight-vue{border-radius:4px}code.highlight-vue{padding:2px 4px!important}";
styleInject(css_248z);

/* script */
var __vue_script__ = script;
/* template */

/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = undefined;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/__vue_normalize__({}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
